@@ -1,9 +1,12 @@
-require 'test/unit'
+require 'minitest/autorun'
 require 'wavefile.rb'
+require 'wavefile_io_test_helper.rb'
 
 include WaveFile
 
-class BufferTest < Test::Unit::TestCase
+class BufferTest < Minitest::Test
+  include WaveFileIOTestHelper
+
   def test_convert
     old_format = Format.new(:mono, :pcm_16, 44100)
     new_format = Format.new(:stereo, :pcm_16, 22050)
@@ -38,52 +41,56 @@ class BufferTest < Test::Unit::TestCase
 
 
   def test_convert_buffer_channels
-    Format::SUPPORTED_BITS_PER_SAMPLE[:pcm].each do |bits_per_sample|
+    SUPPORTED_BITS_PER_SAMPLE[:pcm].each do |bits_per_sample|
+      format_code = "pcm_#{bits_per_sample}".to_sym
+
       [44100, 22050].each do |sample_rate|
         # Assert that not changing the number of channels is a no-op
-        b = Buffer.new([-100, 0, 200], Format.new(:mono, bits_per_sample, sample_rate))
-        b.convert!(Format.new(:mono, bits_per_sample, sample_rate))
+        b = Buffer.new([-100, 0, 200], Format.new(:mono, format_code, sample_rate))
+        b.convert!(Format.new(:mono, format_code, sample_rate))
         assert_equal([-100, 0, 200], b.samples)
 
         # Mono => Stereo
-        b = Buffer.new([-100, 0, 200], Format.new(:mono, bits_per_sample, sample_rate))
-        b.convert!(Format.new(:stereo, bits_per_sample, sample_rate))
+        b = Buffer.new([-100, 0, 200], Format.new(:mono, format_code, sample_rate))
+        b.convert!(Format.new(:stereo, format_code, sample_rate))
         assert_equal([[-100, -100], [0, 0], [200, 200]], b.samples)
 
         # Mono => 3-channel
-        b = Buffer.new([-100, 0, 200], Format.new(:mono, bits_per_sample, sample_rate))
-        b.convert!(Format.new(3, bits_per_sample, sample_rate))
+        b = Buffer.new([-100, 0, 200], Format.new(:mono, format_code, sample_rate))
+        b.convert!(Format.new(3, format_code, sample_rate))
         assert_equal([[-100, -100, -100], [0, 0, 0], [200, 200, 200]], b.samples)
 
         # Stereo => Mono
-        b = Buffer.new([[-100, -100], [0, 0], [200, 50], [8, 1]], Format.new(:stereo, bits_per_sample, sample_rate))
-        b.convert!(Format.new(:mono, bits_per_sample, sample_rate))
+        b = Buffer.new([[-100, -100], [0, 0], [200, 50], [8, 1]], Format.new(:stereo, format_code, sample_rate))
+        b.convert!(Format.new(:mono, format_code, sample_rate))
         assert_equal([-100, 0, 125, 4], b.samples)
 
         # 3-channel => Mono
         b = Buffer.new([[-100, -100, -100], [0, 0, 0], [200, 50, 650], [5, 1, 1], [5, 1, 2]],
-                       Format.new(3, bits_per_sample, sample_rate))
-        b.convert!(Format.new(:mono, bits_per_sample, sample_rate))
+                       Format.new(3, format_code, sample_rate))
+        b.convert!(Format.new(:mono, format_code, sample_rate))
         assert_equal([-100, 0, 300, 2, 2], b.samples)
 
         # 3-channel => Stereo
         b = Buffer.new([[-100, -100, -100], [1, 2, 3], [200, 50, 650]],
-                       Format.new(3, bits_per_sample, sample_rate))
-        b.convert!(Format.new(:stereo, bits_per_sample, sample_rate))
+                       Format.new(3, format_code, sample_rate))
+        b.convert!(Format.new(:stereo, format_code, sample_rate))
         assert_equal([[-100, -100], [1, 2], [200, 50]], b.samples)
 
         # Unsupported conversion (4-channel => 3-channel)
         b = Buffer.new([[-100, 200, -300, 400], [1, 2, 3, 4]],
-                       Format.new(4, bits_per_sample, sample_rate))
-        assert_raise(BufferConversionError) { b.convert!(Format.new(3, bits_per_sample, sample_rate)) }
+                       Format.new(4, format_code, sample_rate))
+        assert_raises(BufferConversionError) { b.convert!(Format.new(3, format_code, sample_rate)) }
       end
     end
   end
 
   def test_convert_buffer_bits_per_sample_no_op
-    Format::SUPPORTED_BITS_PER_SAMPLE[:pcm].each do |bits_per_sample|
-      b = Buffer.new([0, 128, 255], Format.new(:mono, bits_per_sample, 44100))
-      b.convert!(Format.new(:mono, bits_per_sample, 44100))
+    SUPPORTED_BITS_PER_SAMPLE[:pcm].each do |bits_per_sample|
+      format_code = "pcm_#{bits_per_sample}".to_sym
+
+      b = Buffer.new([0, 128, 255], Format.new(:mono, format_code, 44100))
+      b.convert!(Format.new(:mono, format_code, 44100))
 
       # Target format is the same as the original format, so the sample data should not change
       assert_equal([0, 128, 255], b.samples)
@@ -139,7 +146,7 @@ class BufferTest < Test::Unit::TestCase
   end
 
   def test_convert_buffer_bits_per_sample_8_to_float
-    Format::SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
+    SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
       float_format = "float_#{bits_per_sample}".to_sym
 
       # Mono
@@ -207,7 +214,7 @@ class BufferTest < Test::Unit::TestCase
   end
 
   def test_convert_buffer_bits_per_sample_16_to_float
-    Format::SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
+    SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
       float_format = "float_#{bits_per_sample}".to_sym
 
       # Mono
@@ -278,7 +285,7 @@ class BufferTest < Test::Unit::TestCase
   end
 
   def test_convert_buffer_bits_per_sample_24_to_float
-    Format::SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
+    SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
       float_format = "float_#{bits_per_sample}".to_sym
 
       # Mono
@@ -350,7 +357,7 @@ class BufferTest < Test::Unit::TestCase
   end
 
   def test_convert_buffer_bits_per_sample_32_to_float
-    Format::SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
+    SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
       float_format = "float_#{bits_per_sample}".to_sym
 
       # Mono
@@ -371,7 +378,7 @@ class BufferTest < Test::Unit::TestCase
   end
 
   def test_convert_buffer_bits_per_sample_float_to_8
-    Format::SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
+    SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
       float_format = "float_#{bits_per_sample}".to_sym
 
       # Mono
@@ -391,7 +398,7 @@ class BufferTest < Test::Unit::TestCase
   end
 
   def test_convert_buffer_bits_per_sample_float_to_16
-    Format::SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
+    SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
       float_format = "float_#{bits_per_sample}".to_sym
 
       # Mono
@@ -411,7 +418,7 @@ class BufferTest < Test::Unit::TestCase
   end
 
   def test_convert_buffer_bits_per_sample_float_to_24
-    Format::SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
+    SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
       float_format = "float_#{bits_per_sample}".to_sym
 
       # Mono
@@ -431,7 +438,7 @@ class BufferTest < Test::Unit::TestCase
   end
 
   def test_convert_buffer_bits_per_sample_float_to_32
-    Format::SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
+    SUPPORTED_BITS_PER_SAMPLE[:float].each do |bits_per_sample|
       float_format = "float_#{bits_per_sample}".to_sym
 
       # Mono
